@@ -19,6 +19,28 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
+#include "seahorse-context.h"
+#include "seahorse-daemon.h"
+#include "seahorse-gconf.h"
+#include "seahorse-gtkstock.h"
+#include "seahorse-secure-memory.h"
+#include "seahorse-unix-signal.h"
+
+#include "common/seahorse-cleanup.h"
+#include "common/seahorse-registry.h"
+
+#ifdef WITH_PGP
+#include "pgp/seahorse-pgp-module.h"
+#endif
+
+#ifdef WITH_SSH
+#include "ssh/seahorse-ssh-module.h"
+#endif
+
+#include <glib/gi18n.h>
+
 #include <sys/types.h>
 #include <sys/signal.h>
 
@@ -30,16 +52,6 @@
 #include <syslog.h>
 #include <fcntl.h>
 
-#include <gnome.h>
-
-#include "config.h"
-#include "seahorse-daemon.h"
-#include "seahorse-secure-memory.h"
-#include "seahorse-gconf.h"
-#include "seahorse-gtkstock.h"
-#include "seahorse-context.h"
-#include "seahorse-unix-signal.h"
-
 static gboolean daemon_no_daemonize = FALSE;
 static gboolean daemon_running = FALSE;
 static gboolean daemon_quit = FALSE;
@@ -166,16 +178,9 @@ prepare_logging ()
     g_log_set_handler ("Gnome", flags, log_handler, NULL);
 }
 
-static void
-client_die ()
-{
-    gtk_main_quit ();
-}
-
 int main(int argc, char* argv[])
 {
     SeahorseOperation *op;
-    GnomeClient *client = NULL;
     GOptionContext *octx = NULL;
 
     seahorse_secure_memory_init ();
@@ -183,10 +188,7 @@ int main(int argc, char* argv[])
     octx = g_option_context_new ("");
     g_option_context_add_main_entries (octx, options, GETTEXT_PACKAGE);
 
-    gnome_program_init ("seahorse-daemon", VERSION, LIBGNOMEUI_MODULE, argc, argv,
-                    GNOME_PARAM_GOPTION_CONTEXT, octx,
-                    GNOME_PARAM_HUMAN_READABLE_NAME, _("Encryption Daemon (Seahorse)"),
-                    GNOME_PARAM_APP_DATADIR, DATA_DIR, NULL);
+    gtk_init_with_args (&argc, &argv, _("Encryption Daemon (Seahorse)"), (GOptionEntry *) options, GETTEXT_PACKAGE, NULL);
 
     /* 
      * All functions after this point have to print messages 
@@ -202,9 +204,6 @@ int main(int argc, char* argv[])
     if (!daemon_no_daemonize)
         seahorse_gconf_disconnect ();    
         
-    client = gnome_master_client();
-    g_signal_connect(client, "die", G_CALLBACK(client_die), NULL);
-    
     /* We log to the syslog */
     prepare_logging ();
 
@@ -212,9 +211,17 @@ int main(int argc, char* argv[])
     seahorse_gtkstock_init ();
     seahorse_gtkstock_add_icons (daemon_icons);
     
+    /* Load the various components */
+#ifdef WITH_PGP
+    seahorse_registry_load_types (NULL, SEAHORSE_PGP_REGISTRY);
+#endif
+#ifdef WITH_SSH
+    seahorse_registry_load_types (NULL, SEAHORSE_SSH_REGISTRY);
+#endif
+
     /* Make the default SeahorseContext */
     seahorse_context_new (SEAHORSE_CONTEXT_APP | SEAHORSE_CONTEXT_DAEMON, 0);
-    op = seahorse_context_load_local_keys (SCTX_APP ());
+    op = seahorse_context_load_local_objects (SCTX_APP ());
     g_object_unref (op);
     
     /* Initialize the various daemon components */
@@ -239,6 +246,7 @@ int main(int argc, char* argv[])
     seahorse_dbus_server_cleanup ();
 
     seahorse_context_destroy (SCTX_APP ());
+    seahorse_cleanup_perform ();
 
     return 0;
 }
