@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,16 @@
  
 #include "config.h"
 
-#include <gtk/gtk.h>
-#include <glib.h>
+#include <string.h>
+#include <libintl.h>
 
+#include <gtk/gtk.h>
+
+#include <glib.h>
+#include <glib/gi18n.h>
+
+#include "seahorse-key.h"
+#include "seahorse-object.h"
 #include "seahorse-libdialogs.h"
 #include "seahorse-util.h"
 
@@ -49,7 +56,7 @@ typedef struct _SeahorseNotification {
     gchar *message;
     const gchar *icon;
 
-    GList *keys;
+    GList *objects;
     GObject *widget;
     
 } SeahorseNotification;
@@ -65,20 +72,20 @@ G_DEFINE_TYPE (SeahorseNotification, seahorse_notification, G_TYPE_OBJECT);
  */
 
 /* Forward Declaration */
-static void key_changed (SeahorseKey *skey, SeahorseKeyChange change, SeahorseNotification *snotif);
+static void object_changed (SeahorseObject *sobj, SeahorseObjectChange change, SeahorseNotification *snotif);
 
 static void
-insert_key_field (GString *res, const gchar *key, const gchar *field)
+insert_key_field (GString *res, const gchar *id, const gchar *field)
 {
-    SeahorseKey *skey;
+    SeahorseObject *sobj;
     GValue value;
     GValue svalue;
     gchar *str;
     guint uid;
     
-    skey = seahorse_context_key_from_dbus (SCTX_APP (), key, &uid);
-    if (!skey) {
-        g_warning ("key '%s' in key text does not exist", key);
+    sobj = seahorse_context_object_from_dbus (SCTX_APP (), id, &uid);
+    if (!sobj || !SEAHORSE_IS_KEY (sobj)) {
+        g_warning ("key '%s' in key text does not exist", id);
         return;
     }
     
@@ -89,7 +96,7 @@ insert_key_field (GString *res, const gchar *key, const gchar *field)
     memset (&value, 0, sizeof (value));
     memset (&svalue, 0, sizeof (value));
     
-    if (seahorse_key_lookup_property (skey, uid, field, &value)) {
+    if (seahorse_key_lookup_property (SEAHORSE_KEY (sobj), uid, field, &value)) {
         g_value_init (&svalue, G_TYPE_STRING);
         if (g_value_transform (&value, &svalue)) {
             str = g_markup_escape_text (g_value_get_string (&svalue), -1);
@@ -358,7 +365,7 @@ setup_fallback_notification (SeahorseNotification *snotif, gboolean urgent,
 }
 
 static void 
-key_changed (SeahorseKey *skey, SeahorseKeyChange change, SeahorseNotification *snotif)
+object_changed (SeahorseObject *sobj, SeahorseObjectChange change, SeahorseNotification *snotif)
 {
     if (!snotif->widget)
         return;
@@ -377,7 +384,7 @@ keys_start_element (GMarkupParseContext *ctx, const gchar *element_name,
                     gpointer user_data, GError **error)
 {
     SeahorseNotification* snotif = SEAHORSE_NOTIFICATION (user_data);
-    SeahorseKey *skey;
+    SeahorseObject *sobj;
 
     if (strcmp (element_name, "key") == 0) {
         
@@ -395,10 +402,10 @@ keys_start_element (GMarkupParseContext *ctx, const gchar *element_name,
             g_warning ("key text <key> element requires the following attributes\n"
                        "     <key id=\"xxxxx\" field=\"xxxxx\"/>");
         
-        skey = seahorse_context_key_from_dbus (SCTX_APP (), key, NULL);
-        if (skey) {
-            snotif->keys = g_list_append (snotif->keys, skey);
-            g_signal_connect (skey, "changed", G_CALLBACK (key_changed), snotif);
+        sobj = seahorse_context_object_from_dbus (SCTX_APP (), key, NULL);
+        if (sobj) {
+            snotif->objects = g_list_append (snotif->objects, sobj);
+            g_signal_connect (sobj, "changed", G_CALLBACK (object_changed), snotif);
         }
     }
     
@@ -432,10 +439,10 @@ seahorse_notification_dispose (GObject *gobject)
 
     snotif->widget = NULL;
     
-    for (l = snotif->keys; l; l = g_list_next (l)) 
-        g_signal_handlers_disconnect_by_func (l->data, key_changed, snotif);
-    g_list_free (snotif->keys);
-    snotif->keys = NULL;
+    for (l = snotif->objects; l; l = g_list_next (l)) 
+        g_signal_handlers_disconnect_by_func (l->data, object_changed, snotif);
+    g_list_free (snotif->objects);
+    snotif->objects = NULL;
     
     G_OBJECT_CLASS (seahorse_notification_parent_class)->dispose (gobject);
 }
@@ -564,9 +571,7 @@ seahorse_notify_import (guint keynum, gchar **keys)
     else {
         body = g_strdup_printf(ngettext("Imported a key for", "Imported keys for", keynum));
         
-        keyptr = keys;
-        
-        for (keyptr; *keyptr; keyptr++) {
+        for (keyptr = keys; *keyptr; keyptr++) {
             t = g_strdup_printf ("%s\n<key id='%s' field=\"display-name\"/>", body, *keyptr);
             g_free (body);
             body = t;
@@ -590,98 +595,3 @@ seahorse_notify_import_local (guint keys, GtkWidget *attachto)
                                    FALSE, ICON_PREFIX "seahorse-key.png", attachto);
     g_free (body);
 }
-
-void
-seahorse_notify_signatures (const gchar* data, gpgme_verify_result_t status)
-{
-    const gchar *icon = NULL;
-    gchar *title, *body;
-    gboolean sig = FALSE;
-    GSList *rawids;
-    GList *keys;
-    SeahorseKey *skey;
-    
-    /* Discover the key in question */
-    rawids = g_slist_append (NULL, status->signatures->fpr);
-    keys = seahorse_context_discover_keys (SCTX_APP (), SKEY_PGP, rawids);
-    g_slist_free (rawids);
-    
-    g_return_if_fail (keys != NULL);
-    skey = SEAHORSE_KEY (keys->data);
-    g_list_free (keys);
-
-    /* Figure out what to display */
-    switch (gpgme_err_code (status->signatures->status))  {
-    case GPG_ERR_KEY_EXPIRED:
-	/* TRANSLATORS: <key id='xxx'> is a custom markup tag, do not translate. */
-        body = _("Signed by <i><key id='%s'/> <b>expired</b></i> on %s.");
-        title = _("Invalid Signature");
-        icon = ICON_PREFIX "seahorse-sign-bad.png";
-        sig = TRUE;
-        break;
-	/* TRANSLATORS: <key id='xxx'> is a custom markup tag, do not translate. */
-    case GPG_ERR_SIG_EXPIRED:
-        body = _("Signed by <i><key id='%s'/></i> on %s <b>Expired</b>.");
-        title = _("Expired Signature");
-        icon = ICON_PREFIX "seahorse-sign-bad.png";
-        sig = TRUE;
-        break;
-	/* TRANSLATORS: <key id='xxx'> is a custom markup tag, do not translate. */
-    case GPG_ERR_CERT_REVOKED:
-        body = _("Signed by <i><key id='%s'/> <b>Revoked</b></i> on %s.");
-        title = _("Revoked Signature");
-        icon = ICON_PREFIX "seahorse-sign-bad.png";
-        sig = TRUE;
-        break;
-    case GPG_ERR_NO_ERROR:
-	/* TRANSLATORS: <key id='xxx'> is a custom markup tag, do not translate. */
-        body = _("Signed by <i><key id='%s'/></i> on %s.");
-        title = _("Good Signature");
-        icon = ICON_PREFIX "seahorse-sign-ok.png";
-        sig = TRUE;
-        break;
-    case GPG_ERR_NO_PUBKEY:
-        body = _("Signing key not in keyring.");
-        title = _("Unknown Signature");
-        icon = ICON_PREFIX "seahorse-sign-unknown.png";
-        break;
-    case GPG_ERR_BAD_SIGNATURE:
-        body = _("Bad or forged signature. The signed data was modified.");
-        title = _("Bad Signature");
-        icon = ICON_PREFIX "seahorse-sign-bad.png";
-        break;
-    case GPG_ERR_NO_DATA:
-        return;
-    default:
-        if (!GPG_IS_OK (status->signatures->status)) 
-            seahorse_util_handle_gpgme (status->signatures->status, 
-                                        _("Couldn't verify signature."));
-        return;
-    };
-
-    if (sig) {
-        gchar *date = seahorse_util_get_display_date_string (status->signatures->timestamp);
-        gchar *id = seahorse_context_keyid_to_dbus (SCTX_APP (), seahorse_key_get_keyid (skey), 0);
-        body = g_markup_printf_escaped (body, id, date);
-        g_free (date);
-        g_free (id);
-    } else {
-        body = g_strdup (body);
-    }
-    
-    if (data) {
-        data = seahorse_util_uri_get_last (data);
-        title = g_strdup_printf ("%s: %s", data, title); 
-    } else {
-        title = g_strdup (title);
-    }
-
-    /* Always try and display in the daemon */
-    if (seahorse_context_is_daemon (SCTX_APP ()))
-        seahorse_notification_display (title, body, !sig, icon, NULL);
-    else
-        cryptui_display_notification (title, body, icon, !sig);
-
-    g_free (title);
-    g_free (body);
-}    
