@@ -18,20 +18,21 @@
  * 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
-#include <gnome.h>
-
 #include "config.h"
-#include "seahorse-prefs.h"
-#include "seahorse-util.h"
+
+#include <glib/gi18n.h>
+
 #include "seahorse-check-button-control.h"
 #include "seahorse-combo-keys.h"
-#include "seahorse-keyserver-control.h"
-#include "seahorse-server-source.h"
 #include "seahorse-gconf.h"
-#include "seahorse-pgp-key.h"
 #include "seahorse-gtkstock.h"
+#include "seahorse-keyserver-control.h"
+#include "seahorse-prefs.h"
 #include "seahorse-secure-entry.h"
+#include "seahorse-servers.h"
+#include "seahorse-util.h"
+
+#include "common/seahorse-registry.h"
 
 /* From seahorse-prefs-cache.c */
 void seahorse_prefs_cache (SeahorseWidget *widget);
@@ -60,7 +61,7 @@ keyserver_cell_edited (GtkCellRendererText *cell, gchar *path, gchar *text,
     GtkTreeIter iter;
     gboolean ret;
     
-    if (!seahorse_server_source_valid_uri (text)) {
+    if (!seahorse_servers_is_valid_uri (text)) {
         seahorse_util_show_error (NULL, _("Not a valid Key Server address."), 
                                   _("For help contact your system adminstrator or the administrator of the key server." ));
         return;
@@ -224,8 +225,6 @@ gconf_notify (GConfClient *client, guint id, GConfEntry *entry, SeahorseWidget *
         /* Change list of GConfValue to list of strings */
         for (ks = NULL, l = gconf_value_get_list (value); l; l = l->next) 
             ks = g_slist_append (ks, (gchar*)gconf_value_get_string (l->data));
-        
-		ks = seahorse_server_source_purge_keyservers (ks);
         populate_keyservers (swidget, ks);
         g_slist_free (l); /* We don't own string values */
     }
@@ -272,7 +271,7 @@ calculate_keyserver_uri (SeahorseWidget *swidget)
     
     /* Custom URI? */
     if (scheme == NULL) {
-        if (seahorse_server_source_valid_uri (host))
+        if (seahorse_servers_is_valid_uri (host))
             return g_strdup (host);
         return NULL;
     }
@@ -286,7 +285,7 @@ calculate_keyserver_uri (SeahorseWidget *swidget)
         port = NULL;
     
     uri = g_strdup_printf("%s://%s%s%s", scheme, host, port ? ":" : "", port ? port : "");
-    if (!seahorse_server_source_valid_uri (uri)) {
+    if (!seahorse_servers_is_valid_uri (uri)) {
         g_free (uri);
         uri = NULL;
     }
@@ -350,26 +349,30 @@ keyserver_add_clicked (GtkButton *button, SeahorseWidget *sw)
     widget = glade_xml_get_widget (swidget->xml, "keyserver-type");
     g_return_if_fail (widget != NULL);
     
-    /* The list of types, plus the null 'custom' type */
-    types = seahorse_server_source_get_types ();
-    types = g_slist_append (types, g_strdup (""));
-    g_object_set_data_full (G_OBJECT (swidget), "keyserver-types", types, 
-                            (GDestroyNotify)seahorse_util_string_slist_free);
+    /* The list of types */
+    types = seahorse_servers_get_types ();
     
     /* The description for the key server types, plus custom */
-    descriptions = seahorse_server_source_get_descriptions ();
+    descriptions = NULL;
+    for (l = types; l; l = g_slist_next (l))
+	    descriptions = g_slist_append (descriptions, seahorse_servers_get_description (l->data));
     descriptions = g_slist_append (descriptions, g_strdup (_("Custom")));
     
     gtk_combo_box_remove_text (GTK_COMBO_BOX (widget), 0);    
     for (l = descriptions; l; l = g_slist_next (l))
-        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), l->data);
+        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), l->data ? l->data : "");
     gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
     seahorse_util_string_slist_free (descriptions);
 
+    /* Save these away for later */
+    types = g_slist_append (types, g_strdup (""));
+    g_object_set_data_full (G_OBJECT (swidget), "keyserver-types", types, 
+                            (GDestroyNotify)seahorse_util_string_slist_free);
+
     glade_xml_signal_connect_data (swidget->xml, "on_uri_changed", 
                                    G_CALLBACK (uri_changed), swidget);
 
-    response = gtk_dialog_run (GTK_DIALOG (seahorse_widget_get_top (swidget)));
+    response = gtk_dialog_run (GTK_DIALOG (seahorse_widget_get_toplevel (swidget)));
     if (response == GTK_RESPONSE_ACCEPT) {
         
         result = calculate_keyserver_uri (swidget);
@@ -401,8 +404,7 @@ setup_keyservers (SeahorseWidget *swidget)
     GSList *ks;
     guint notify_id;
     
-    ks = seahorse_gconf_get_string_list (KEYSERVER_KEY);
-	ks = seahorse_server_source_purge_keyservers (ks);
+    ks = seahorse_servers_get_uris ();
     populate_keyservers (swidget, ks);
     seahorse_util_string_slist_free (ks);
     
@@ -422,7 +424,7 @@ setup_keyservers (SeahorseWidget *swidget)
             
     notify_id = seahorse_gconf_notify (KEYSERVER_KEY, (GConfClientNotifyFunc)gconf_notify, 
                                        swidget);
-    g_signal_connect (seahorse_widget_get_top (swidget), "destroy", 
+    g_signal_connect (seahorse_widget_get_toplevel (swidget), "destroy", 
                         G_CALLBACK (gconf_unnotify), GINT_TO_POINTER (notify_id));
                         
     w = glade_xml_get_widget (swidget->xml, "keyserver-publish");
@@ -468,28 +470,6 @@ setup_sharing (SeahorseWidget *swidget)
 
 /* -------------------------------------------------------------------------- */
 
-static void
-default_key_changed (GtkComboBox *combo, gpointer *data)
-{
-    GQuark keyid = seahorse_combo_keys_get_active_id (combo);
-    seahorse_gconf_set_string (SEAHORSE_DEFAULT_KEY, keyid == 0 ? "" : g_quark_to_string (keyid));
-}
-
-static void
-gconf_notification (GConfClient *gclient, guint id, GConfEntry *entry, 
-                    GtkComboBox *combo)
-{
-    GQuark keyid = g_quark_from_string (gconf_value_get_string (gconf_entry_get_value (entry)));
-    seahorse_combo_keys_set_active_id (combo, keyid);
-}
-
-static void
-remove_gconf_notification (GObject *obj, gpointer data)
-{
-    guint gconf_id = GPOINTER_TO_INT (data);
-    seahorse_gconf_unnotify (gconf_id);
-}
-
 /**
  * seahorse_prefs_new
  * 
@@ -500,43 +480,13 @@ remove_gconf_notification (GObject *obj, gpointer data)
 SeahorseWidget *
 seahorse_prefs_new (GtkWindow *parent)
 {
-    SeahorseKeyset *skset;
     SeahorseWidget *swidget;
-    GtkWidget *widget;
-    guint gconf_id;
+#ifndef WITH_KEYSERVER
+    GtkWidget *widget = NULL;
+#endif
     
     swidget = seahorse_widget_new ("prefs", parent);
     
-    widget = glade_xml_get_widget (swidget->xml, "encrypt-self");
-    seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), ENCRYPTSELF_KEY);
-    
-    widget = glade_xml_get_widget (swidget->xml, "signer-select");
-    g_return_val_if_fail (widget != NULL, NULL);
-
-    skset = seahorse_keyset_new (SKEY_PGP, 
-                                 SKEY_PRIVATE, 
-                                 SKEY_LOC_LOCAL, 
-                                 SKEY_FLAG_CAN_SIGN, 
-                                 SKEY_FLAG_EXPIRED | SKEY_FLAG_REVOKED | SKEY_FLAG_DISABLED);
-    seahorse_combo_keys_attach (GTK_COMBO_BOX (widget), skset, _("None. Prompt for a key."));
-    g_object_unref (skset);
-    
-    seahorse_combo_keys_set_active_id (GTK_COMBO_BOX (widget), 
-                                       g_quark_from_string (seahorse_gconf_get_string (SEAHORSE_DEFAULT_KEY)));
-    g_signal_connect (widget, "changed", G_CALLBACK (default_key_changed), NULL);
-
-    gconf_id = seahorse_gconf_notify (SEAHORSE_DEFAULT_KEY, 
-                                      (GConfClientNotifyFunc)gconf_notification, GTK_COMBO_BOX (widget));
-    g_signal_connect (widget, "destroy", G_CALLBACK (remove_gconf_notification), GINT_TO_POINTER (gconf_id));
-    
-#ifdef WITH_AGENT   
-    seahorse_prefs_cache (swidget);
-#else
-    widget = glade_xml_get_widget (swidget->xml, "cache-tab");
-    g_return_val_if_fail (GTK_IS_WIDGET (widget), swidget);
-    seahorse_prefs_remove_tab (swidget, widget);
-#endif
-
 #ifdef WITH_KEYSERVER
     setup_keyservers (swidget);
 #else
