@@ -29,7 +29,6 @@
 
 #include <gtk/gtk.h>
 #include <time.h>
-#include <gpgme.h>
 
 #include "config.h"
 #include "seahorse-context.h"
@@ -39,6 +38,8 @@
 const AvahiPoll* seahorse_util_dns_sd_get_poll ();
 #endif
 
+struct _SeahorseKey;
+
 typedef enum {
     SEAHORSE_CRYPT_SUFFIX,
     SEAHORSE_SIG_SUFFIX,
@@ -53,35 +54,29 @@ gchar*		seahorse_util_get_date_string		    (const time_t		time);
 gchar*		seahorse_util_get_display_date_string   (const time_t		time);
 
 
-#define SEAHORSE_GPGME_ERROR  (seahorse_util_gpgme_error_domain ())
-
-GQuark      seahorse_util_gpgme_error_domain ();
-
 #define SEAHORSE_ERROR  (seahorse_util_error_domain ())
 
 GQuark      seahorse_util_error_domain ();
 
-void        seahorse_util_gpgme_to_error        (gpgme_error_t gerr, 
-                                                 GError** err);
-
-void        seahorse_util_show_error            (GtkWindow          *parent,
+void        seahorse_util_show_error            (GtkWidget          *parent,
                                                  const gchar        *heading,
                                                  const gchar        *message);
                                                  
-void        seahorse_util_handle_gpgme          (gpgme_error_t      err,
-                                                 const gchar*       desc, ...);
-
 void        seahorse_util_handle_error          (GError*            err,
                                                  const char*        desc, ...);
 
-gchar*      seahorse_util_write_data_to_text    (gpgme_data_t       data,
+gboolean    seahorse_util_prompt_delete         (const gchar *text);
+
+gchar*      seahorse_util_read_to_text          (GInputStream *     input,
                                                  guint              *len);
 
 guint       seahorse_util_read_data_block       (GString            *buf, 
-                                                 gpgme_data_t       data, 
+                                                 GInputStream*      input, 
                                                  const gchar        *start, 
                                                  const gchar*       end);
 
+gsize       seahorse_util_memory_output_length  (GMemoryOutputStream *output);
+
 gboolean    seahorse_util_print_fd          (int fd, 
                                              const char* data);
 
@@ -101,8 +96,6 @@ const gchar* seahorse_util_uri_get_last     (const gchar* uri);
 
 const gchar* seahorse_util_uri_split_last   (gchar* uri);
 
-gchar**     seahorse_util_uris_expand       (const gchar **uris);
-
 gboolean    seahorse_util_uris_package      (const gchar* package, 
                                              const gchar** uris);
 
@@ -117,22 +110,25 @@ gboolean    seahorse_util_write_file_private            (const gchar* filename,
                                                          const gchar* contents,
                                                          GError **err);
 
-GtkWidget*  seahorse_util_chooser_open_new              (const gchar *title,
+GtkDialog*  seahorse_util_chooser_open_new              (const gchar *title,
                                                          GtkWindow *parent);
 
-GtkWidget*  seahorse_util_chooser_save_new              (const gchar *title,
+GtkDialog*  seahorse_util_chooser_save_new              (const gchar *title,
                                                          GtkWindow *parent);
 
-void        seahorse_util_chooser_show_key_files        (GtkWidget *dialog);
+void        seahorse_util_chooser_show_key_files        (GtkDialog *dialog);
 
-void        seahorse_util_chooser_show_archive_files    (GtkWidget *dialog);
+void        seahorse_util_chooser_show_archive_files    (GtkDialog *dialog);
 
-void        seahorse_util_chooser_set_filename          (GtkWidget *dialog, 
+void        seahorse_util_chooser_set_filename_full     (GtkDialog *dialog, 
                                                          GList *keys);
 
-gchar*      seahorse_util_chooser_open_prompt           (GtkWidget *dialog);
+void        seahorse_util_chooser_set_filename          (GtkDialog *dialog, 
+                                                         struct _SeahorseKey *skey);
 
-gchar*      seahorse_util_chooser_save_prompt           (GtkWidget *dialog);
+gchar*      seahorse_util_chooser_open_prompt           (GtkDialog *dialog);
+
+gchar*      seahorse_util_chooser_save_prompt           (GtkDialog *dialog);
 
 gboolean	seahorse_util_check_suffix		(const gchar		*path,
                                              SeahorseSuffix     suffix);
@@ -148,13 +144,9 @@ gchar**     seahorse_util_strvec_dup        (const gchar        **vec);
 
 guint       seahorse_util_strvec_length       (const gchar      **vec);
 
-gpgme_key_t* seahorse_util_keylist_to_keys    (GList *keys);
+GList*       seahorse_util_objects_sort       (GList *objects);
 
-GList*       seahorse_util_keylist_sort       (GList *keys);
-
-GList*       seahorse_util_keylist_splice     (GList *keys);
-
-void         seahorse_util_free_keys          (gpgme_key_t* keys);
+GList*       seahorse_util_objects_splice     (GList *objects);
 
 gboolean    seahorse_util_string_equals       (const gchar *s1, const gchar *s2);
 
