@@ -2,7 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2003 Jacob Perkins
- * Copyright (C) 2004,2005 Nate Nielsen
+ * Copyright (C) 2004,2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,43 +20,42 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
-#include <gnome.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <locale.h>
+#include "config.h"
 
 #include "seahorse-context.h"
-#include "seahorse-windows.h"
 #include "seahorse-util.h"
 #include "seahorse-libdialogs.h"
-#include "seahorse-pgp-source.h"
-#include "seahorse-pgp-key.h"
 #include "seahorse-gtkstock.h"
 #include "seahorse-secure-memory.h"
 
+#include "seahorse-key-manager.h"
+
+#include "common/seahorse-cleanup.h"
+#include "common/seahorse-registry.h"
+
+#ifdef WITH_PGP
+#include "pgp/seahorse-pgp-module.h"
+#endif
+
+#ifdef WITH_SSH
+#include "ssh/seahorse-ssh-module.h"
+#endif
+
+#include "gkr/seahorse-gkr-module.h"
+
+#include <locale.h>
+#include <stdlib.h>
+  
+#include <glib/gi18n.h>
+
 /* Initializes context and preferences, then loads key manager */
 int
 main (int argc, char **argv)
 {
     SeahorseOperation *op = NULL;
-    GtkWindow* win;
     int ret = 0;
 
-    seahorse_secure_memory_init (65536);
-    
-    /* We need to drop privileges completely for security */
-#if defined(HAVE_SETRESUID) && defined(HAVE_SETRESGID)
-
-    /* Not in header files for all OSs, even where present */
-    int setresuid(uid_t ruid, uid_t euid, uid_t suid);
-    int setresgid(gid_t rgid, gid_t egid, gid_t sgid);
-  
-    if (setresuid (getuid (), getuid (), getuid ()) == -1 ||
-        setresgid (getgid (), getgid (), getgid ()) == -1)
-#else
-    if (setuid (getuid ()) == -1 || setgid (getgid ()) == -1)
-#endif
-        g_error (_("couldn't drop privileges properly"));
+    seahorse_secure_memory_init ();
     
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
@@ -64,31 +63,32 @@ main (int argc, char **argv)
     textdomain (GETTEXT_PACKAGE);
 #endif
 
-    g_message("init gpgme version %s", gpgme_check_version(NULL));
-
-#ifdef ENABLE_NLS
-    gpgme_set_locale(NULL, LC_CTYPE, setlocale(LC_CTYPE, NULL));
-    gpgme_set_locale(NULL, LC_MESSAGES, setlocale(LC_MESSAGES, NULL));
-#endif
-
-    gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
-                       GNOME_PARAM_HUMAN_READABLE_NAME, _("Encryption Key Manager"),
-                       GNOME_PARAM_APP_DATADIR, DATA_DIR, NULL);
+    gtk_init_with_args (&argc, &argv, _("Encryption Key Manager"), NULL, GETTEXT_PACKAGE, NULL);
 
     /* Insert Icons into Stock */ 
-    seahorse_gtkstock_init();
+    seahorse_gtkstock_init ();
+    
+    /* Initialize the various components */
+#ifdef WITH_PGP
+    seahorse_registry_load_types (NULL, SEAHORSE_PGP_REGISTRY);
+#endif
+#ifdef WITH_SSH
+    seahorse_registry_load_types (NULL, SEAHORSE_SSH_REGISTRY);
+#endif
     
     /* Make the default SeahorseContext */
     seahorse_context_new (SEAHORSE_CONTEXT_APP, 0);
-    op = seahorse_context_load_local_keys (SCTX_APP());
+    op = seahorse_context_load_local_objects (SCTX_APP ());
 
-    win = seahorse_key_manager_show (op);
-    g_signal_connect_after (G_OBJECT (win), "destroy", gtk_main_quit, NULL);
+    /* Load these components after loading local keys */
+    seahorse_registry_load_types (NULL, SEAHORSE_GKR_REGISTRY);
+
+    seahorse_key_manager_show (op);
+    g_signal_connect_after (SCTX_APP (), "destroy", gtk_main_quit, NULL);
     
     gtk_main ();
-    
-    if (gnome_vfs_initialized ())
-        gnome_vfs_shutdown ();
-    
+
+
+    seahorse_cleanup_perform ();
     return ret;
 }
