@@ -19,18 +19,15 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
 
-#include "seahorse-widget.h"
-#include "seahorse-gpgmex.h"
-#include "seahorse-util.h"
-#include "seahorse-context.h"
-#include "seahorse-windows.h"
-#include "seahorse-preferences.h"
-#include "seahorse-server-source.h"
-#include "seahorse-gconf.h"
 #include "seahorse-context.h"
 #include "seahorse-dns-sd.h"
+#include "seahorse-gconf.h"
+#include "seahorse-keyserver-results.h"
+#include "seahorse-preferences.h"
+#include "seahorse-servers.h"
+#include "seahorse-util.h"
+#include "seahorse-widget.h"
 
 typedef struct _KeyserverSelection {
     GSList *names;
@@ -266,8 +263,8 @@ refresh_keyservers (GConfClient *client, guint id, GConfEntry *entry, SeahorseWi
     w = glade_xml_get_widget (swidget->xml, "key-server-list");
     g_return_if_fail (w != NULL);
 
-    keyservers = seahorse_gconf_get_string_list (KEYSERVER_KEY);
-    names = seahorse_server_source_parse_keyservers (keyservers);
+    keyservers = seahorse_servers_get_uris ();
+    names = seahorse_servers_get_names ();
     populate_keyserver_list (swidget, w, keyservers, names);
     
     seahorse_util_string_slist_free (keyservers);
@@ -315,7 +312,7 @@ ok_clicked (GtkButton *button, SeahorseWidget *swidget)
     seahorse_gconf_set_string_list (LASTSERVERS_KEY, 
                                     selection->all ? NULL : selection->names);
                                     
-    op = seahorse_context_load_remote_keys (SCTX_APP(), search);
+    op = seahorse_context_load_remote_objects (SCTX_APP(), search);
     
     /* Open the new result window */    
     seahorse_keyserver_results_show (op, 
@@ -348,7 +345,7 @@ cleanup_signals (GtkWidget *widget, SeahorseWidget *swidget)
  **/
 GtkWindow*
 seahorse_keyserver_search_show (GtkWindow *parent)
-{	
+{
     SeahorseServiceDiscovery *ssd;
 	SeahorseWidget *swidget;
     GtkWindow *win;
